@@ -12,12 +12,12 @@
 #' @family DataBackend
 #' @export
 #' @examples
-#' data = as.data.table(iris)
-#' data$id = seq_len(nrow(iris))
+#' data = as.data.table(palmerpenguins::penguins)
+#' data$id = seq_len(nrow(palmerpenguins::penguins))
 #' b = DataBackendDataTable$new(data = data, primary_key = "id")
 #' print(b)
 #' b$head()
-#' b$data(rows = 100:101, cols = "Species")
+#' b$data(rows = 100:101, cols = "species")
 #'
 #' b$nrow
 #' head(b$rownames)
@@ -26,7 +26,7 @@
 #' b$colnames
 #'
 #' # alternative construction
-#' as_data_backend(iris)
+#' as_data_backend(palmerpenguins::penguins)
 DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
   cloneable = FALSE,
   public = list(
@@ -142,52 +142,3 @@ DataBackendDataTable = R6Class("DataBackendDataTable", inherit = DataBackend,
     }
   )
 )
-
-#' @param data ([data.frame()])\cr
-#'   The input [data.frame()].
-#'   Converted to a [data.table::data.table()] automatically.
-#'
-#' @param keep_rownames (`logical(1)` | `character(1)`)\cr
-#'   If `TRUE` or a single string, keeps the row names of `data` as a new column.
-#'   The column is named like the provided string, defaulting to `"..rownames"` for `keep_rownames == TRUE`.
-#'   Note that the created column will be used as a regular feature by the task unless you manually change the column role.
-#'   Also see [data.table::as.data.table()].
-#'
-#' @rdname as_data_backend
-#' @export
-as_data_backend.data.frame = function(data, primary_key = NULL, keep_rownames = FALSE, ...) {
-  assert_data_frame(data, min.cols = 1L, col.names = "unique")
-  if (!isFALSE(keep_rownames)) {
-    if (isTRUE(keep_rownames)) {
-      keep_rownames = "..rownames"
-    } else {
-      assert_string(keep_rownames)
-    }
-  }
-
-  data = as.data.table(data, keep.rownames = keep_rownames)
-  compact_seq = FALSE
-
-  if (is.character(primary_key)) {
-    assert_string(primary_key)
-    assert_choice(primary_key, colnames(data))
-    assert_integer(data[[primary_key]], any.missing = FALSE, unique = TRUE)
-  } else {
-    if (is.null(primary_key)) {
-      row_ids = seq_row(data)
-      compact_seq = TRUE
-    } else if (is.integer(primary_key)) {
-      row_ids = assert_integer(primary_key, len = nrow(data), any.missing = FALSE, unique = TRUE)
-    } else {
-      stopf("Argument 'primary_key' must be NULL, a column name or a vector of ids")
-    }
-
-    primary_key = "..row_id"
-    data = insert_named(data, list("..row_id" = row_ids))
-  }
-
-  b = DataBackendDataTable$new(data, primary_key)
-  b$compact_seq = compact_seq
-
-  return(b)
-}
