@@ -1,9 +1,3 @@
-#' @rdname PredictionData
-#' @export
-as_prediction.PredictionDataRegr = function(x, check = TRUE) { # nolint
-  invoke(PredictionRegr$new, check = check, .args = x)
-}
-
 #' @rdname PredictionData
 #' @export
 check_prediction_data.PredictionDataRegr = function(pdata) { # nolint
