@@ -57,7 +57,7 @@ ee[["character___factor"]] =
 ee[["character___ordered"]] =
   ee[["logical___ordered"]]
 ee[["character___POSIXct"]] =
-  function(value, type, levels) { x = try(as.POSIXct(value), silent = TRUE); if (inherits(x, "try-error")) value else x }
+  function(value, type, levels) { x = try(as.POSIXct(value, ""), silent = TRUE); if (inherits(x, "try-error")) value else x }
 
 ## from: factor
 ee[["factor___logical"]] =
