@@ -34,7 +34,7 @@
 #' @export
 #' @examples
 #' # benchmarking with benchmark_grid()
-#' tasks = lapply(c("iris", "sonar"), tsk)
+#' tasks = lapply(c("penguins", "sonar"), tsk)
 #' learners = lapply(c("classif.featureless", "classif.rpart"), lrn)
 #' resamplings = rsmp("cv", folds = 3)
 #'
@@ -56,9 +56,9 @@
 #' as.data.table(rr$prediction())
 #'
 #' # Benchmarking with a custom design:
-#' # - fit classif.featureless on iris with a 3-fold CV
+#' # - fit classif.featureless on penguins with a 3-fold CV
 #' # - fit classif.rpart on sonar using a holdout
-#' tasks = list(tsk("iris"), tsk("sonar"))
+#' tasks = list(tsk("penguins"), tsk("sonar"))
 #' learners = list(lrn("classif.featureless"), lrn("classif.rpart"))
 #' resamplings = list(rsmp("cv", folds = 3), rsmp("holdout"))
 #'
@@ -78,7 +78,7 @@
 #' bmr = benchmark(design)
 #' print(bmr)
 #'
-#' ## Get the training set of the 2nd iteration of the featureless learner on iris
+#' ## Get the training set of the 2nd iteration of the featureless learner on penguins
 #' rr = bmr$aggregate()[learner_id == "classif.featureless"]$resample_result[[1]]
 #' rr$resampling$train_set(2)
 benchmark = function(design, store_models = FALSE, store_backends = TRUE) {
@@ -113,19 +113,30 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE) {
   })
   n = nrow(grid)
 
-  lg$info("Benchmark with %i resampling iterations", n)
+  lg$info("Running benchmark with %i resampling iterations", n)
   pb = get_progressor(n)
 
-  lg$debug("Running benchmark() asynchronously with %i iterations", n)
+  if (getOption("mlr3.debug", FALSE)) {
+    lg$info("Running benchmark() sequentially in debug mode with %i iterations", n)
 
-  res = future.apply::future_mapply(workhorse,
-    task = grid$task, learner = grid$learner, resampling = grid$resampling,
-    iteration = grid$iteration,
-    MoreArgs = list(store_models = store_models, lgr_threshold = lg$threshold, pb = pb),
-    SIMPLIFY = FALSE, USE.NAMES = FALSE,
-    future.globals = FALSE, future.scheduling = structure(TRUE, ordering = "random"),
-    future.packages = "mlr3", future.seed = TRUE
-  )
+    res = mapply(workhorse,
+      task = grid$task, learner = grid$learner, resampling = grid$resampling,
+      iteration = grid$iteration,
+      MoreArgs = list(store_models = store_models, lgr_threshold = lg$threshold, pb = pb),
+      SIMPLIFY = FALSE, USE.NAMES = FALSE
+    )
+  } else {
+    lg$debug("Running benchmark() via future with %i iterations", n)
+
+    res = future.apply::future_mapply(workhorse,
+      task = grid$task, learner = grid$learner, resampling = grid$resampling,
+      iteration = grid$iteration,
+      MoreArgs = list(store_models = store_models, lgr_threshold = lg$threshold, pb = pb),
+      SIMPLIFY = FALSE, USE.NAMES = FALSE,
+      future.globals = FALSE, future.scheduling = structure(TRUE, ordering = "random"),
+      future.packages = "mlr3", future.seed = TRUE
+    )
+  }
 
   grid = insert_named(grid, list(
     learner_state = map(res, "learner_state"),
