@@ -34,9 +34,14 @@ mlr_resamplings = R6Class("DictionaryResampling",
 )$new()
 
 #' @export
-as.data.table.DictionaryResampling = function(x, ...) {
+as.data.table.DictionaryResampling = function(x, ...) { # nolint
+
   setkeyv(map_dtr(x$keys(), function(key) {
-    r = x$get(key)
+    r = tryCatch(x$get(key),
+      missingDefaultError = function(e) NULL)
+    if (is.null(r))
+      return(list(key = key))
+
     list(key = key, params = list(r$param_set$ids()), iters = r$iters)
-  }), "key")[]
+  }, .fill = TRUE), "key")[]
 }
