@@ -204,7 +204,8 @@ workhorse = function(iteration, task, learner, resampling, lgr_threshold = NULL,
 
   sets = list(
     train = resampling$train_set(iteration),
-    test = resampling$test_set(iteration)
+    test = resampling$test_set(iteration),
+    validation = task$row_roles$validation
   )
 
   # train model
