@@ -1,18 +1,18 @@
-context("logger")
-
 test_that("log to text file", {
+  # See #566
+  console_appender = if (packageVersion("lgr") >= "0.4.0") lg$inherited_appenders$console else lg$inherited_appenders$appenders.console
   f = tempfile("mlr3test_", fileext = "log")
   th1 = lg$threshold
-  th2 = lg$inherited_appenders$appenders.console$threshold
+  th2 = console_appender$threshold
 
   lg$set_threshold("debug")
   lg$add_appender(lgr::AppenderFile$new(f, threshold = "debug"), name = "testappender")
-  lg$inherited_appenders$appenders.console$set_threshold("warn")
+  console_appender$set_threshold("warn")
 
   on.exit({
     lg$remove_appender("testappender")
     lg$set_threshold(th1)
-    lg$inherited_appenders$appenders.console$set_threshold(th2)
+    console_appender$set_threshold(th2)
   })
 
   task = tsk("iris")
